# Generated by Django 4.2.11 on 2024-05-24 18:32

from django.db import migrations
import re

from hypha.apply.activity.adapters.activity_feed import ActivityAdapter
from hypha.apply.activity.models import TEAM, Activity
from hypha.apply.activity.options import MESSAGES


def get_message_string_regex(msg_str: str) -> str:
    """Replaces all python formatting brackets with a '.*' and adds line start & end tokens"""

    # Will not match escaped curly brackets or anything that doesn't have a somewhat pythonic namespace. https://regex101.com/r/icGuTn/1
    format_brackets_re = r"(?<!\\)\{[a-zA-Z_.]*(?<!\\)\}"
    msg_str_split = re.split(format_brackets_re, msg_str)
    re_str = f"^{'.*'.join([re.escape(seg) for seg in msg_str_split])}$"
    return re_str


def change_updatelead_visibility(apps, schema_editor):
    lead_messages = [
        ActivityAdapter.messages[MESSAGES.UPDATE_LEAD],
        ActivityAdapter.messages[MESSAGES.BATCH_UPDATE_LEAD],
        ActivityAdapter.messages[MESSAGES.UPDATE_PROJECT_LEAD],
        ActivityAdapter.messages[MESSAGES.ARCHIVE_SUBMISSION],
        ActivityAdapter.messages[MESSAGES.UNARCHIVE_SUBMISSION],
    ]

    staff_identity_set = Activity.objects.none()

    for message in lead_messages:
        re_str = get_message_string_regex(message)
        staff_identity_set |= Activity.objects.filter(message__regex=re_str).exclude(
            visibility=TEAM
        )

    for activity in staff_identity_set:
        activity.visibility = TEAM
        activity.save()


class Migration(migrations.Migration):
    dependencies = [
        ("activity", "0081_alter_event_type"),
    ]

    operations = [migrations.RunPython(change_updatelead_visibility)]
